@@ -243,7 +243,9 @@ def set_event(cus_event: dict):
         cus_disable_plugins = []
         component = event.get("Components")
         if component.get("SqlClient") in ("false", "False", "0", False, 0, -1):
-            cus_disable_plugins.extend(["fast_pymysql", "fast_pymongo", "fast_elasticsearch"])
+            cus_disable_plugins.extend(["fast_pymysql"])
+        if component.get("Datastore") in ("false", "False", "0", False, 0, -1):
+            cus_disable_plugins.extend(["fast_pymongo", "fast_elasticsearch", "fast_redis"])
         if component.get("HttpClient") in ("false", "False", "0", False, 0, -1):
             cus_disable_plugins.extend(
                 [
