@@ -5,19 +5,25 @@
     created by FAST-DEV 2021/4/6
 """
 import inspect
-import logging
 import pkgutil
-import traceback
+import re
 import pkg_resources
 from packaging import version
 
 import fast_tracker
-from fast_tracker.loggings import logger
+from fast_tracker import config
 
 
 def install():
+    disable_patterns = config.disable_plugins
+    if isinstance(disable_patterns, str):
+        disable_patterns = [re.compile(p.strip()) for p in disable_patterns.split(',') if p.strip()]
+    else:
+        disable_patterns = [re.compile(p.strip()) for p in disable_patterns if p.strip()]
     # for循环将plugins文件夹下面的所有实现的plugin都install进来
     for importer, modname, ispkg in pkgutil.iter_modules(fast_tracker.plugins.__path__):
+        if any(pattern.match(modname) for pattern in disable_patterns):
+            continue
         plugin = importer.find_module(modname).load_module(modname)
 
         supported = pkg_version_check(plugin)
@@ -31,7 +37,8 @@ def install():
         try:
             plugin.install()
         except Exception as e:
-            print("FAST:Warning:failed to install plugingin %s", modname)
+            from fast_tracker.utils import functions
+            functions.log("FAST:Warning:failed to install plugingin %s", modname)
             pass
 
 
