@@ -23,53 +23,65 @@ def install():
     def params_tostring(params):
         return "\n".join([k + "=" + v for k, v in params.items()])
 
+    def get_url_path(url):
+        split_args = url.split("//")
+        path = split_args[0] if len(split_args) == 1 else split_args[1]
+        path_list = path.split("/")
+        del path_list[0]
+        return "/" + "/".join(path_list)
+
     def _fast_falcon_api(this: API, env, start_response):
-        context = get_context()
-        carrier = Carrier()
-        headers = get_headers(env)
-        trace_id_name = config.get_trace_id_name()
-        trace_id_name = trace_id_name.replace("_", "-") if "_" in trace_id_name else trace_id_name
-        for item in carrier:
-            key = item.key.replace("_", "-") if "_" in item.key else item.key
-            if key.capitalize() in headers:
-                item.val = headers[key.capitalize()]
-            if key.upper() in headers:
-                item.val = headers[key.upper()]
-            if trace_id_name.capitalize() in headers and type(item) is Carrier:
-                item.set_frontend_trace_id(headers[trace_id_name.capitalize()])
-            if trace_id_name.upper() in headers and type(item) is Carrier:
-                item.set_frontend_trace_id(headers[trace_id_name.upper()])
-        with context.new_entry_span(op="/", carrier=carrier) as span:
-            span.layer = Layer.Http
-            span.component = ComponentType.Falcon
+        try:
+            context = get_context()
+            carrier = Carrier()
+            headers = get_headers(env)
+            trace_id_name = config.get_trace_id_name()
+            trace_id_name = trace_id_name.replace("_", "-") if "_" in trace_id_name else trace_id_name
+            for item in carrier:
+                key = item.key.replace("_", "-") if "_" in item.key else item.key
+                if key.capitalize() in headers:
+                    item.val = headers[key.capitalize()]
+                if key.upper() in headers:
+                    item.val = headers[key.upper()]
+                if trace_id_name.capitalize() in headers and type(item) is Carrier:
+                    item.set_frontend_trace_id(headers[trace_id_name.capitalize()])
+                if trace_id_name.upper() in headers and type(item) is Carrier:
+                    item.set_frontend_trace_id(headers[trace_id_name.upper()])
+            with context.new_entry_span(op="/", carrier=carrier) as span:
+                span.layer = Layer.Http
+                span.component = ComponentType.Falcon
 
-            from falcon import RequestOptions
-            req = request.Request(env, RequestOptions())
-            span.op = str(req.url).split("?")[0]
-            span.peer = "%s:%s" % (req.remote_addr, req.port)
-            span.tag(Tag(key=tags.HttpMethod, val=req.method))
-            span.tag(Tag(key=tags.HttpUrl, val=str(req.url)))
-            span.tag(Tag(key=tags.HttpPath, val=str(req.url).split("?")[0]))
-            if req.params:
-                span.tag(
-                    Tag(key=tags.HttpParams, val=params_tostring(req.params)[0:])
-                )
+                from falcon import RequestOptions
 
-            set_code(config.tenant_code_reader, req, "tenant_code")
-            set_code(config.user_code_reader, req, "user_code")
-            set_code(config.env_code_reader, req, "env_code")
+                req = request.Request(env, RequestOptions())
+                span.op = str(req.url).split("?")[0]
+                span.peer = "%s:%s" % (req.remote_addr, req.port)
+                http_path = get_url_path(str(req.url).split("?")[0])
+                span.tag(Tag(key=tags.HttpMethod, val=req.method))
+                span.tag(Tag(key=tags.HttpUrl, val=str(req.url)))
+                span.tag(Tag(key=tags.HttpPath, val=http_path))
+                if req.params:
+                    span.tag(Tag(key=tags.HttpParams, val=params_tostring(req.params)[0:]))
 
-            resp = _original_falcon_api(this, env, start_response)
+                set_code(config.tenant_code_reader, req, "tenant_code")
+                set_code(config.user_code_reader, req, "user_code")
+                set_code(config.env_code_reader, req, "env_code")
 
-            from falcon import ResponseOptions
+                resp = _original_falcon_api(this, env, start_response)
 
-            resp_obj = response.Response(ResponseOptions())
+                from falcon import ResponseOptions
 
-            resp_status = parse_status(resp_obj.status)
-            if int(resp_status[0]) >= 400:
-                span.error_occurred = True
+                resp_obj = response.Response(ResponseOptions())
 
-            return resp
+                resp_status = parse_status(resp_obj.status)
+                if int(resp_status[0]) >= 400:
+                    span.error_occurred = True
+
+                return resp
+        except Exception as e:
+            from fast_tracker.utils import functions
+
+            functions.log("探针falcon插件发生错误，错误信息：%r", str(e))
 
     def _fast_handle_exception(this: API, req, resp, ex, params):
         if ex is not None:
@@ -98,8 +110,8 @@ def install():
         elif reader_type == ReaderType.RequestHeader:
             # 下划线转中横杠
             code = ""
-            if '_' in reader.get("ReaderKey"):
-                reader["ReaderKey"] = reader.get("ReaderKey").replace('_', '-')
+            if "_" in reader.get("ReaderKey"):
+                reader["ReaderKey"] = reader.get("ReaderKey").replace("_", "-")
             if reader.get("ReaderKey") in request.headers:
                 code = request.headers[reader.get("ReaderKey")]
             elif reader.get("ReaderKey").upper() in request.headers:
