@@ -62,12 +62,27 @@ def _gen_fast_get_response_func(old_execute):
                     # self.request.connection.context.address  get ('::1', 52857, 0, 0) sometimes got error
                     span.peer = self.request.host  # got like: localhost:8888
                 except BaseException as e:
-                    span.peer = self.request.headers.get("X-Real-IP") or \
-                            self.request.headers.get("X-Forwarded-For") or \
-                            self.request.remote_ip  # ::1
+                    span.peer = (
+                        self.request.headers.get("X-Real-IP")
+                        or self.request.headers.get("X-Forwarded-For")
+                        or self.request.remote_ip
+                    )  # ::1
                     pass
+                temp_args = request.arguments
+                temp_arg = []
+                for key, arg in temp_args.items():
+                    val = []
+                    for i in arg:
+                        val.append(i.decode("utf-8"))
+                    temp_arg.append(str(key) + "=" + ",".join(val))
+                temp_arg = "&".join(temp_arg)
+                http_url = (
+                    "{}://{}{}?{}".format(request.protocol, request.host, request.path, temp_arg)
+                    if temp_arg
+                    else "{}://{}{}".format(request.protocol, request.host, request.path)
+                )
                 span.tag(Tag(key=tags.HttpMethod, val=request.method))
-                span.tag(Tag(key=tags.HttpUrl, val="{}://{}{}".format(request.protocol, request.host, request.path)))
+                span.tag(Tag(key=tags.HttpUrl, val=http_url))
                 # HttpPath 只需要获取PATH_INFO信息即可，不需要？后的内容
                 span.tag(Tag(key=tags.HttpPath, val=(request.path).split("?")[0]))
                 result = old_execute(self, *args, **kwargs)
@@ -112,9 +127,11 @@ def _gen_fast_get_response_func(old_execute):
                     # self.request.connection.context.address  get ('::1', 52857, 0, 0) sometimes got error
                     span.peer = self.request.host
                 except BaseException as e:
-                    span.peer = self.request.headers.get("X-Real-IP") or \
-                            self.request.headers.get("X-Forwarded-For") or \
-                            self.request.remote_ip  # ::1
+                    span.peer = (
+                        self.request.headers.get("X-Real-IP")
+                        or self.request.headers.get("X-Forwarded-For")
+                        or self.request.remote_ip
+                    )  # ::1
                     pass
                 temp_args = request.arguments
                 temp_arg = []
@@ -124,8 +141,13 @@ def _gen_fast_get_response_func(old_execute):
                         val.append(i.decode("utf-8"))
                     temp_arg.append(str(key) + "=" + ",".join(val))
                 temp_arg = "&".join(temp_arg)
+                http_url = (
+                    "{}://{}{}?{}".format(request.protocol, request.host, request.path, temp_arg)
+                    if temp_arg
+                    else "{}://{}{}".format(request.protocol, request.host, request.path)
+                )
                 span.tag(Tag(key=tags.HttpMethod, val=request.method))
-                span.tag(Tag(key=tags.HttpUrl, val="{}://{}{}?{}".format(request.protocol, request.host, request.path, temp_arg)))
+                span.tag(Tag(key=tags.HttpUrl, val=http_url))
                 result = yield from old_execute(self, *args, **kwargs)
                 span.tag(Tag(key=tags.HttpStatus, val=self._status_code, overridable=True))
                 if self._status_code >= 400:
