@@ -4,11 +4,12 @@
 """
     created by FAST-DEV 2021/4/9
 """
-import threading
 import time
 import sys
 import os
 
+from fast_tracker import config
+
 
 def lower_case_name(text):
     """
@@ -33,8 +34,8 @@ def log(text, *args, level=1):
     :param int level: 日志级别, 数字越高，打印信息越多，为0表示不打印日志。暂定级别有：0，1，2，3，4 可对应为logging的日志级别
     :return:
     """
-    startup_debug = os.environ.get("FAST_DEBUG", "off").lower() in ("on", "true", "1")
-    debug_level = int(os.environ.get('FAST_DEBUG_LEVEL', 0))
+    startup_debug = config.debug
+    debug_level = config.debug_level
     if startup_debug:
         if debug_level >= level:
             text = text % args
